==> derby-0.0.10.tgz: package/examples/chat/lib/chat/index.js <==
var NUM_USER_IMAGES, get, getRoom, ready, view, _ref;
_ref = require('derby').createApp(module), get = _ref.get, view = _ref.view, ready = _ref.ready;
NUM_USER_IMAGES = 10;
get('/:room?', function(page, model, _arg) {
  var room, userId, _room;
  room = _arg.room;
  if (!(room && /^[-\w ]+$/.test(room))) {
    return page.redirect('/lobby');
  }
  _room = room.toLowerCase().replace(/[_ ]/g, '-');
  if (_room !== room) {
    return page.redirect("/" + _room);
  }
  if (userId = model.get('_session.userId')) {
    return getRoom(page, model, room, userId);
  }
  return model.async.incr('nextUserId', function(err, userId) {
    model.set('_session.userId', userId);
    model.set("users." + userId, {
      name: 'User ' + userId,
      picClass: 'pic' + (userId % NUM_USER_IMAGES)
    });
    return getRoom(page, model, room, userId);
  });
});
getRoom = function(page, model, room, userId) {
  return model.subscribe({
    _room: "rooms." + room
  }, 'users', function() {
    model.setNull('_room.messages', []);
    model.set('_user', model.ref("users." + userId));
    model.set('_newComment', '');
    model.set('_numMessages', model.get('_room.messages').length);
    return page.render();
  });
};
view.after('message', function() {
  return $('messages').scrollTop = $('messageList').offsetHeight;
});
ready(function(model) {
  model.set('_showReconnect', true);
  exports.connect = function() {
    model.set('_showReconnect', false);
    setTimeout((function() {
      return model.set('_showReconnect', true);
    }), 1000);
    return model.socket.socket.connect();
  };
  exports.reload = function() {
    return window.location.reload();
  };
  model.on('push', '_room.messages', function() {
    return model.incr('_numMessages');
  });
  return exports.postMessage = function() {
    model.push('_room.messages', {
      userId: model.get('_session.userId'),
      comment: model.get('_newComment')
    });
    return model.set('_newComment', '');
  };
});

==> derby-0.1.0.tgz: package/examples/chat/lib/chat/index.js <==
var NUM_USER_IMAGES, get, getRoom, ready, view, _ref;
_ref = require('derby').createApp(module), get = _ref.get, view = _ref.view, ready = _ref.ready;
NUM_USER_IMAGES = 10;
get('/:room?', function(page, model, _arg) {
  var room, userId, _room;
  room = _arg.room;
  if (!(room && /^[-\w ]+$/.test(room))) {
    return page.redirect('/lobby');
  }
  _room = room.toLowerCase().replace(/[_ ]/g, '-');
  if (_room !== room) {
    return page.redirect("/" + _room);
  }
  if (userId = model.get('_session.userId')) {
    return getRoom(page, model, room, userId);
  }
  return model.async.incr('nextUserId', function(err, userId) {
    model.set('_session.userId', userId);
    model.set("users." + userId, {
      name: 'User ' + userId,
      picClass: 'pic' + (userId % NUM_USER_IMAGES)
    });
    return getRoom(page, model, room, userId);
  });
});
getRoom = function(page, model, room, userId) {
  return model.subscribe({
    _room: "rooms." + room
  }, 'users', function() {
    model.setNull('_room.messages', []);
    model.set('_user', model.ref("users." + userId));
    model.set('_newComment', '');
    model.set('_numMessages', model.get('_room.messages').length);
    return page.render();
  });
};
view.after('message', function() {
  return $('messages').scrollTop = $('messageList').offsetHeight;
});
ready(function(model) {
  var displayTime, i, message, messagePath, months, time, _len, _ref2;
  months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];
  displayTime = function(time) {
    var hours, minutes, period;
    time = new Date(time);
    hours = time.getHours();
    period = hours < 12 ? ' am, ' : ' pm, ';
    hours = (hours % 12) || 12;
    minutes = time.getMinutes();
    if (minutes < 10) {
      minutes = '0' + minutes;
    }
    return hours + ':' + minutes + period + months[time.getMonth()] + ' ' + time.getDate() + ', ' + time.getFullYear();
  };
  _ref2 = model.get('_room.messages');
  for (i = 0, _len = _ref2.length; i < _len; i++) {
    message = _ref2[i];
    messagePath = "_room.messages." + i;
    if (time = model.get(messagePath + '.time')) {
      model.set(messagePath + '._displayTime', displayTime(time));
    }
  }
  model.set('_showReconnect', true);
  exports.connect = function() {
    model.set('_showReconnect', false);
    setTimeout((function() {
      return model.set('_showReconnect', true);
    }), 1000);
    return model.socket.socket.connect();
  };
  exports.reload = function() {
    return window.location.reload();
  };
  model.on('push', '_room.messages', function(message) {
    var len;
    len = model.incr('_numMessages');
    return model.set('_room.messages.' + (len - 1) + '._displayTime', displayTime(message.time));
  });
  return exports.postMessage = function() {
    model.push('_room.messages', {
      userId: model.get('_session.userId'),
      comment: model.get('_newComment'),
      time: +new Date
    });
    return model.set('_newComment', '');
  };
});
